@@ -26,7 +26,6 @@
 #' spread_groups(mtcars_grouped_summary, vs, am, .group_sep = "__")
 #'
 #' spread_groups(mtcars_grouped_summary, vs, am, .col_sep = "__")
-#'
 #' @export
 spread_groups <- function(.tbl, ..., .group_sep = ".", .col_sep = "._.") {
   tbl_ungrouped <- ungroup(.tbl)
@@ -51,7 +50,7 @@ spread_groups <- function(.tbl, ..., .group_sep = ".", .col_sep = "._.") {
 
   # Check if all rule columns are logical
   is_all_rules_lgl <- tbl_ungrouped %>%
-    select(!!! rule_syms) %>%
+    select(!!!rule_syms) %>%
     vapply(is.logical, TRUE) %>%
     all()
   if (!is_all_rules_lgl) {
@@ -61,15 +60,18 @@ spread_groups <- function(.tbl, ..., .group_sep = ".", .col_sep = "._.") {
   group_id_sym <- rlang::sym(keyholder::compute_id_name(rule_cols))
 
   tbl_ungrouped %>%
-    tidyr::unite(!! group_id_sym, ...,
-                 sep = .group_sep, remove = TRUE) %>%
-    tidyr::gather(key = "rule_name", value = "value",
-                  !!! rule_syms) %>%
-    tidyr::unite(col = "var_rule",
-                 !! group_id_sym, .data[["rule_name"]],
-                 sep = .col_sep, remove = TRUE) %>%
+    tidyr::unite(!!group_id_sym, ..., sep = .group_sep, remove = TRUE) %>%
+    tidyr::gather(key = "rule_name", value = "value", !!!rule_syms) %>%
+    tidyr::unite(
+      col = "var_rule",
+      !!group_id_sym,
+      .data[["rule_name"]],
+      sep = .col_sep,
+      remove = TRUE
+    ) %>%
     # For preserving ordering by rule and then by variable
-    mutate(var_rule = factor(.data$var_rule,
-                             levels = unique(.data$var_rule))) %>%
+    mutate(
+      var_rule = factor(.data$var_rule, levels = unique(.data$var_rule))
+    ) %>%
     tidyr::spread(key = "var_rule", value = "value")
 }
